<?php
// **********************************************************************// 
// ! Supports post thumbnails and post formats
// **********************************************************************// 
add_theme_support( 'post-thumbnails' );
add_theme_support( 'custom-logo', array(
   'height'      => 85,
   'width'       => 90,
   'flex-width' => true,
) );
function morgan_the_custom_logo() {
   if ( function_exists( 'the_custom_logo' ) ) {
      the_custom_logo();
   }
}
// **********************************************************************// 
// ! Rss feeds, Custom Background and Title Tag theme supports
// **********************************************************************// 
add_theme_support( 'automatic-feed-links' );
add_theme_support('custom-background', array(
        'default-color' => '#fafafa',
    ));
add_theme_support( 'custom-header', array(
		'default-text-color'     => '#000'
	) );
add_theme_support( 'title-tag' );
function morgan_add_editor_styles() {
    add_editor_style( 'css/webfonts/webfonts.css' );
}
add_action( 'admin_init', 'morgan_add_editor_styles' );

// **********************************************************************// 
// ! This theme uses wp_nav_menu() for Main Menu
// **********************************************************************// 
register_nav_menus( array(
		'morgan_primary_menu'=> esc_html__('Main Menu', 'morgan')
) );

// **********************************************************************// 
// ! Register Sidebars
// **********************************************************************//
if ( ! function_exists( 'morgan_widgets_init' ) ) {
	function morgan_widgets_init() {

		register_sidebar( array(
		'name' => esc_html__( 'Sidebar', 'morgan' ),
		'id' => 'morgan_sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div><div class="clearfix"></div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
	) );
	}
}
add_action( 'widgets_init', 'morgan_widgets_init' );

/*********************************
Custom Google Font Lato
********************************/
function morgan_google_font_lato() {
$fonts_url = 'https://fonts.googleapis.com/css?family=Lato:300,400,700';
return esc_url_raw( $fonts_url );
}

// **********************************************************************// 
// ! Get Global Variables
// **********************************************************************//
function morgan_get_global_post() {
    global $post;
    if ( 
        ! $post instanceof \WP_Post
    ) {
        return false;
    }
    return $post;
}

function morgan_get_global_wpquery() {
    global $wp_query;
    return $wp_query;
}

// **********************************************************************// 
// ! Get Blog Pages
// **********************************************************************//
function is_blog () {
    return ( is_archive() || is_author() || is_category() || is_home() || is_single() || is_tag() );
}

// **********************************************************************// 
// ! Custom Pagination
// **********************************************************************//
function morgan_custom_pagination() {
	global $wp_query;

	$big = 999999999; // need an unlikely integer
		
	echo paginate_links( array(
		'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' => '?paged=%#%',
		'current' => max( 1, get_query_var('paged') ),
		'total' => $wp_query->max_num_pages,
		'show_all'     => false,
		'end_size'     => 1,
		'mid_size'     => 2,
		'prev_next'    => true,
		'prev_text'    => '<i class="ti-angle-left"></i>',
		'next_text'    => '<i class="ti-angle-right"></i>',
		'type'         => 'list',
		'add_args'     => false,
		'add_fragment' => ''
	) );
}

// **********************************************************************// 
// ! Function to Check if Extensions Plugin is Active
// **********************************************************************// 
function morgan_is_extensions_plugin_active() {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	if ( function_exists( 'the_morgan_extensions' ) ) {
		return true;
	} else {
		return false;
	}
}

// **********************************************************************// 
// ! Function to Check if Extensions Plugin is Active
// **********************************************************************// 
function morgan_copyright_text_fn() {
	$theme_data = wp_get_theme();
	$theme_uri = $theme_data->get('ThemeURI');
	if ( morgan_is_extensions_plugin_active() ) {
		$t_plugin_data = get_plugin_data(trailingslashit( ABSPATH ) . 'wp-content/plugins/the_morgan_extensions/the_morgan_extensions.php');
		$t_item_ver = $t_plugin_data['Version'];
		if ($t_item_ver >= 1.2) {
				if(morgan_get_option('copy_text') != '') {
					echo esc_textarea( morgan_get_option('copy_text') );
				} else {
					if (function_exists('morgan_footer_function')) {
						morgan_footer_function();
					}
				}
		} else {
			if (function_exists('morgan_footer_function')) {
				morgan_footer_function();
			}
		}
	} else { 
			echo '<a href="https://fluentthemes.com/">'.esc_html__('Desinged and Developed by', 'morgan').' Fluent-Themes Team</a>';
	}
}
// **********************************************************************// 
// ! Excerpt Limit
// **********************************************************************//
function morgan_excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }	
  $excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
  return $excerpt;
}

if ( ! function_exists( 'morgan_excerpt_length' ) ) {
	function morgan_excerpt_length( $length ) {
	return 65;
	}
}
add_filter( 'excerpt_length', 'morgan_excerpt_length', 999 );

// **********************************************************************// 
// ! Set Content Width
// **********************************************************************// 
if (!isset($content_width)) { $content_width = 750; }

// **********************************************************************// 
// ! Display Comments section
// **********************************************************************//
if ( ! function_exists( 'morgan_comment' ) ) {
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own morgan_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
	function morgan_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;

	global $post;
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
	<div class="img"><?php echo get_avatar($comment, 120); ?></div>
            <div class="text">
              <h4 class="lessmar"><?php comment_author(); ?> </h4>
              <p class="padd_bot1"><?php comment_date('d M, Y') ?></p>
              <?php comment_text()?>
            </div>
	<!-- #comment-## -->

	<?php
	}
}

/*******************
Comment form styling
*******************/
if ( ! function_exists( 'morgan_modify_comment_fields' ) ) {
	function morgan_modify_comment_fields($fields) {

    $fields['fields'] = '<div class="contact-form">
                    	';
	$n_value = '';
	$e_value = '';
	
	$fields['fields'] .= '<div class="col-md-6">
                            	<label>
                                	<i class="ti-user"></i>
										<input type="text" placeholder="'.esc_attr__("Name", 'morgan').'" id="author" name="author" value="'.esc_attr($n_value).'" aria-required="true" />
                                </label>                          	
                            </div>';
	

	$fields['fields'] .= '<div class="col-md-6">
                            	<label>
	                                <i class="ti-email"></i>
									<input type="text" placeholder="'.esc_attr__("E-mail", 'morgan').'" id="email" name="email" value="'.esc_attr($e_value).'" aria-required="true" />
                                </label>
                            </div>';
	return $fields;
	}
}

add_filter('comment_form_defaults', 'morgan_modify_comment_fields');//Name, Email and Website fields customization filter

if ( ! function_exists( 'morgan_comment_field' ) ) {
	function morgan_comment_field($arg) {
  
	$arg['comment_field'] = '<div class="col-md-12">
                            	<textarea placeholder="'.esc_attr__("Leave Message", 'morgan').'" name="comment" id="comment" rows="4" ></textarea>
							';    
	return $arg;
	}
}
add_filter('comment_form_defaults', 'morgan_comment_field');//Text area customization filter


function morgan_comment_form_submit_button($button) {
	$button =
		'<div class="btn-submit">
                                	<button name="submit" type="submit" id="[args:id_submit]" value="[args:label_submit]"><i class="ti-email"></i>'.esc_html__("Submit comment", 'morgan').'</button>
                                </div>
                            </div>
		 
		 </div>
                    	' .
		get_comment_id_fields();
	return $button;
}
add_filter('comment_form_submit_button', 'morgan_comment_form_submit_button');//Submit button customization filter

function morgan_move_comment_field_to_bottom( $fields ) {
$comment_field = $fields['comment'];
unset( $fields['comment'] );
$fields['comment'] = $comment_field;

return $fields;
}
add_filter( 'comment_form_fields', 'morgan_move_comment_field_to_bottom' );//move the comment text field to the bottom